==> PhysX-4.0.0.zip: PhysX-4.0.0/physx/documentation/PhysXAPI/files/structPxConcreteType.js <==
var structPxConcreteType =
[
    [ "Enum", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8", [
      [ "eUNDEFINED", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ae532e94bf1c5c2deac15d6ecc9e96ac6", null ],
      [ "eHEIGHTFIELD", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0b7794c6d7c176b457e45ce84f9efb4a", null ],
      [ "eCONVEX_MESH", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a82eb74ec3cb3500943f14c6b587ec606", null ],
      [ "eTRIANGLE_MESH_BVH33", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ab6ae11318fb26a00eff8864beaa1290d", null ],
      [ "eTRIANGLE_MESH_BVH34", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a59470211a58ba63a20540005c76fd767", null ],
      [ "eRIGID_DYNAMIC", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8aa7f7c318076dc92e78f9b23c75cf591d", null ],
      [ "eRIGID_STATIC", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a927c0cfacf7985ca89a0084e2d2b552a", null ],
      [ "eSHAPE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ab6585d569ee421acfeadc5d89adf3bc3", null ],
      [ "eMATERIAL", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8aba56f4ba8a534856e101ffb7d6fef757", null ],
      [ "eCONSTRAINT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a16cd44fb372accd877e9ceef294f424f", null ],
      [ "eAGGREGATE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a3edb3b8e6daab37cfeb242b840dc5731", null ],
      [ "eARTICULATION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a61a0e7164c97f640baaf56916a2ba761", null ],
      [ "eARTICULATION_LINK", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a94841b56bdad372addb96f488a9b9f3b", null ],
      [ "eARTICULATION_JOINT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a41858b9270c1bb6f9ff81652ee5668f8", null ],
      [ "ePRUNING_STRUCTURE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a9cfa4bbab08af1a894d4d3cf196ade84", null ],
      [ "eBVH_STRUCTURE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a57e53b71d3577c41378c5e829ebf8408", null ],
      [ "ePHYSX_CORE_COUNT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0ff66b28d98136906e07b15b396d7a1f", null ],
      [ "eFIRST_PHYSX_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ac2bbf4877545a3ced65d6057f643fd54", null ],
      [ "eFIRST_VEHICLE_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0156649a63242d4a34c1c69af29eb92a", null ],
      [ "eFIRST_USER_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ad6da0b02403dd6002e67bbbb489b221e", null ]
    ] ]
];

==> PhysX-4.1.zip: PhysX-4.1/physx/documentation/PhysXAPI/files/structPxConcreteType.js <==
var structPxConcreteType =
[
    [ "Enum", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8", [
      [ "eUNDEFINED", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ae532e94bf1c5c2deac15d6ecc9e96ac6", null ],
      [ "eHEIGHTFIELD", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0b7794c6d7c176b457e45ce84f9efb4a", null ],
      [ "eCONVEX_MESH", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a82eb74ec3cb3500943f14c6b587ec606", null ],
      [ "eTRIANGLE_MESH_BVH33", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ab6ae11318fb26a00eff8864beaa1290d", null ],
      [ "eTRIANGLE_MESH_BVH34", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a59470211a58ba63a20540005c76fd767", null ],
      [ "eRIGID_DYNAMIC", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8aa7f7c318076dc92e78f9b23c75cf591d", null ],
      [ "eRIGID_STATIC", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a927c0cfacf7985ca89a0084e2d2b552a", null ],
      [ "eSHAPE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ab6585d569ee421acfeadc5d89adf3bc3", null ],
      [ "eMATERIAL", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8aba56f4ba8a534856e101ffb7d6fef757", null ],
      [ "eCONSTRAINT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a16cd44fb372accd877e9ceef294f424f", null ],
      [ "eAGGREGATE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a3edb3b8e6daab37cfeb242b840dc5731", null ],
      [ "eARTICULATION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a61a0e7164c97f640baaf56916a2ba761", null ],
      [ "eARTICULATION_REDUCED_COORDINATE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a993fe98b452ae2bf67f63fdd38d6895c", null ],
      [ "eARTICULATION_LINK", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a94841b56bdad372addb96f488a9b9f3b", null ],
      [ "eARTICULATION_JOINT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a41858b9270c1bb6f9ff81652ee5668f8", null ],
      [ "eARTICULATION_JOINT_REDUCED_COORDINATE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ad0b03d874bccbc262188e9c7663ec21c", null ],
      [ "ePRUNING_STRUCTURE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a9cfa4bbab08af1a894d4d3cf196ade84", null ],
      [ "eBVH_STRUCTURE", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a57e53b71d3577c41378c5e829ebf8408", null ],
      [ "ePHYSX_CORE_COUNT", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0ff66b28d98136906e07b15b396d7a1f", null ],
      [ "eFIRST_PHYSX_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ac2bbf4877545a3ced65d6057f643fd54", null ],
      [ "eFIRST_VEHICLE_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8a0156649a63242d4a34c1c69af29eb92a", null ],
      [ "eFIRST_USER_EXTENSION", "structPxConcreteType.html#ad762aca1d4c8fffae41267fae4f1b8e8ad6da0b02403dd6002e67bbbb489b221e", null ]
    ] ]
];
